@@ -4,41 +4,41 @@ data_location = os.path.join(__dir__, "data")
 src = "https://github.com/picolibc/picolibc"
 
 # Module version
-version_str = "1.7.5.post126"
-version_tuple = (1, 7, 5, 126)
+version_str = "1.7.6.post184"
+version_tuple = (1, 7, 6, 184)
 try:
     from packaging.version import Version as V
-    pversion = V("1.7.5.post126")
+    pversion = V("1.7.6.post184")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.7.5.post0"
-data_version_tuple = (1, 7, 5, 0)
+data_version_str = "1.7.6.post56"
+data_version_tuple = (1, 7, 6, 56)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.7.5.post0")
+    pdata_version = V("1.7.6.post56")
 except ImportError:
     pass
-data_git_hash = "f3981f6c16a7b690f1697c9a7f986964bc2e386f"
-data_git_describe = "1.7.5-0-gf3981f6c1"
+data_git_hash = "c60f7e0c32f5cbd16757e1899fecd350ba168a78"
+data_git_describe = "1.7.6-56-gc60f7e0c3"
 data_git_msg = """\
-commit f3981f6c16a7b690f1697c9a7f986964bc2e386f
+commit c60f7e0c32f5cbd16757e1899fecd350ba168a78
 Author: Keith Packard <keithp@keithp.com>
-Date:   Mon Mar 7 22:59:36 2022 -0800
+Date:   Tue May 17 16:03:10 2022 -0700
 
-    Version 1.7.5
+    .github: Add a cmake test
     
     Signed-off-by: Keith Packard <keithp@keithp.com>
 
 """
 
 # Tool version info
-tool_version_str = "0.0.post126"
-tool_version_tuple = (0, 0, 126)
+tool_version_str = "0.0.post128"
+tool_version_tuple = (0, 0, 128)
 try:
     from packaging.version import Version as V
-    ptool_version = V("0.0.post126")
+    ptool_version = V("0.0.post128")
 except ImportError:
     pass
 
